@@ -59,7 +59,8 @@ class ModelLoader(Generic[GenericDbType]):
             if field.endswith('_id') or field.endswith('_ids'):
                 raw_field = field[:field.find("_id")]
                 if raw_field in model._meta.m2m_fields:
-                    m2m_model = model._meta.fields_map[raw_field].model
+                    m2m_model = model._meta.fields_map[raw_field].related_model
+                    m2m_model = m2m_model if m2m_model != model else model._meta.fields_map[raw_field].model
                     if not isinstance(value, (list, set)):
                         value = [value]
                     m2m_entities = await m2m_model.filter(id__in=value)
@@ -126,7 +127,8 @@ class ModelLoader(Generic[GenericDbType]):
             if field.endswith('_id') or field.endswith('_ids'):
                 raw_field = field[:field.find("_id")]
                 if raw_field in model._meta.m2m_fields:
-                    m2m_model = model._meta.fields_map[raw_field].model
+                    m2m_model = model._meta.fields_map[raw_field].related_model
+                    m2m_model = m2m_model if m2m_model != model else model._meta.fields_map[raw_field].model
                     if not isinstance(value, (list, set)):
                         value = [value]
                     m2m_entities = await m2m_model.filter(id__in=value)
